#pragma once

#include <stdint.h>
#include "range.hpp"


namespace Voltmeter
{
    struct Configuration
    {
        static constexpr uint16_t const SamplesN = 3600;
        static constexpr uint16_t const DigitsN = 3;

        uint32_t validityBeacon;
        Range range;
        bool autoRange;
        uint8_t volume;
        bool backlight;
        uint32_t calibration[4];

        constexpr Configuration()
            : validityBeacon(0xaa55aa55ul)
            , range(Range::_4V)
            , autoRange(true)
            , volume(3)
            , backlight(false)
            , calibration { 0, 0, 0, 0 }
        {}

        void Read();
        void Write();

        uint32_t GetCalibration(Range const range);
        void SetCalibration(Range const range, uint32_t value);
    };
}