#pragma once

#include <stdint.h>
#include <avr/io.h>
#include <util/twi.h>


namespace Devices::I2c
{
    enum class Direction 
    {
        Transmit = 0,
        Receive = 1
    };


    inline void Init()
    {
        TWSR = 0x00;
        TWCR = 0x00;
    }


    inline bool Configure(int32_t f)
    {
        int16_t k = F_CPU / f;

        if (k <= 16)
        {
            return false;
        }

        TWBR = (k - 16) / 2;
        return true;
    }


    inline void WaitForInt()
    {
        while (!(TWCR & _BV(TWINT)));
    }


    inline void SendStartCondition()
    {
        TWCR = _BV(TWINT) | _BV(TWEN) | _BV(TWSTA);
    }


    inline void SendStartConditionInt()
    {
        TWCR = _BV(TWINT) | _BV(TWEN) | _BV(TWIE) | _BV(TWSTA);
    }


    inline void SendStopCondition()
    {
        TWCR = _BV(TWINT) | _BV(TWEN) | _BV(TWSTO);
        while (TWCR & _BV(TWSTO));
    }


    inline void SendByte(uint8_t byte)
    {
        TWDR = byte;
        TWCR = _BV(TWINT) | _BV(TWEN);
    }


    inline void SendByteInt(uint8_t byte)
    {
        TWDR = byte;
        TWCR = _BV(TWINT) | _BV(TWEN) | _BV(TWIE);
    }


    inline void AckByte()
    {
        TWCR = _BV(TWINT) | _BV(TWEA) | _BV(TWEN);
    }


    inline void NackByte()
    {
        TWCR = _BV(TWINT) | _BV(TWEN);
    }


    inline void ReceiveByte(uint8_t & byte)
    {
        byte = TWDR;
    }


    inline void GoIdle()
    {
        TWCR = 0;
    }


    inline void DisableInt()
    {
        /* Clear InterruptEnable bit, but don't write INT bit, so it doesn't get cleared */
        TWCR &= ~_BV(TWIE) & ~_BV(TWINT);
    }


    inline uint8_t GetStatus()
    {
        return TWSR & TW_STATUS_MASK;
    }
}